@@ -258,6 +258,7 @@ Type objective_function<Type>::operator()()
 
   DATA_IVECTOR(sim_re); // sim random effects? 0,1; order: omega, epsilon, zeta, IID, RW, smoothers
   DATA_IVECTOR(simulate_t); // sim this specific time step? (used for forecasting)
+  DATA_INTEGER(sim_obs);
 
   DATA_VECTOR(lwr); // lower bound for censpois on counts
   DATA_VECTOR(upr); // upper bound for censpois on counts
@@ -671,17 +672,25 @@ Type objective_function<Type>::operator()()
           }
         } else if (ar1_time) { // type = 'ar1'
           rho_time(k, m) = sdmTMB::minus_one_to_one(rho_time_unscaled(k, m));
+          Type ar1_sigma = sqrt(Type(1) - rho_time(k, m) * rho_time(k, m));
           jnll += SCALE(AR1(rho_time(k, m)), sigma_V(k,m))(vector<Type>(b_rw_t.col(m).col(k)));
-          if (sim_re(4)) {
-            // https://kaskr.github.io/adcomp/classdensity_1_1AR1__t.html
-            vector<Type> tmp(n_t);
-            Type ar1_sigma = sqrt(Type(1) - rho_time(k, m) * rho_time(k, m));
-            Type x0 = rnorm(Type(0), sigma_V(k,m));
-            tmp(0) = rho_time(k, m) * x0 + ar1_sigma * rnorm(Type(0), sigma_V(k,m));
-            for (int t = 1; t < n_t; t++)
-              tmp(t) = rho_time(k, m) * tmp(t-1) + ar1_sigma * rnorm(Type(0), sigma_V(k,m));
-            for(int t = 0; t < n_t; t++)
-              if (simulate_t(t)) SIMULATE{b_rw_t(t, k, m) = tmp(t);}
+          for (int t = 0; t < n_t; t++) {
+            if (t == 0) {
+              if (sim_re(4) && simulate_t(t)) {
+                // https://kaskr.github.io/adcomp/classdensity_1_1AR1__t.html
+                SIMULATE{
+                  b_rw_t(t, k, m) = rho_time(k, m) * rnorm(Type(0), sigma_V(k,m)) + 
+                    ar1_sigma * rnorm(Type(0), sigma_V(k,m));
+                }
+              }
+            } else {
+              if (sim_re(4) && simulate_t(t)) {
+                SIMULATE{
+                  b_rw_t(t, k, m) = rho_time(k, m) * b_rw_t(t-1, k, m) + 
+                    ar1_sigma * rnorm(Type(0), sigma_V(k,m));
+                }
+              }
+            }
           }
         } else {
           error("Time-varying type not found.");
@@ -769,6 +778,8 @@ Type objective_function<Type>::operator()()
   eta_iid_re_i.setZero();
   mu_i.setZero();
   eta_i.setZero();
+  matrix<Type> devresid(n_i,n_m);
+  devresid.setZero();
 
   vector<Type> poisson_link_m0_ll(n_i);
 
@@ -821,8 +832,11 @@ Type objective_function<Type>::operator()()
         if (m == 0) {
           if (y_i(i,0) > Type(0.0)) {
             poisson_link_m0_ll(i) = log_p; // calc ll here; more robust than dbinom_robust(logit(p))
+            devresid(i,m) = sqrt(-2.0 * log_p);
+            // dev = -2 * logmu1;
           } else {
             poisson_link_m0_ll(i) = log_one_minus_p; // log(1 - p)
+            devresid(i,m) = sqrt(-2.0 * log_one_minus_p);
           }
           mu_i(i,0) = exp(log_p); // just for recording; not used in ll b/c robustness
         }
@@ -868,15 +882,25 @@ Type objective_function<Type>::operator()()
     break;
   }
 
+  if (!sim_obs) {
+    for (int m = 0; m < n_m; m++) {
+      for (int i = 0; i < n_i; i++) {
+        y_i(i,m) = mu_i(i,m);
+      }
+    }
+  }
+
   vector<Type> jnll_obs(n_i); // for cross validation
   jnll_obs.setZero();
+
   for (int m = 0; m < n_m; m++) PARALLEL_REGION {
     for (int i = 0; i < n_i; i++) {
       bool notNA = !sdmTMB::isNA(y_i(i,m));
         switch (family(m)) {
           case gaussian_family: {
             if (notNA) tmp_ll = dnorm(y_i(i,m), mu_i(i,m), phi(m), true);
-            SIMULATE{y_i(i,m) = rnorm(mu_i(i,m), phi(m));}
+            if (sim_obs) SIMULATE{y_i(i,m) = rnorm(mu_i(i,m), phi(m));}
+            if (notNA) devresid(i,m) = y_i(i,m) - mu_i(i,m);
             break;
           }
           case tweedie_family: {
@@ -889,34 +913,41 @@ Type objective_function<Type>::operator()()
               if (stan_flag) jnll -= thetaf - 2 * log(1 + exp(thetaf)); // Jacobian adjustment
             }
             if (notNA) tmp_ll = dtweedie(y_i(i,m), mu_i(i,m), phi(m), tweedie_p, true);
-            SIMULATE{y_i(i,m) = rtweedie(mu_i(i,m), phi(m), tweedie_p);}
+            if (sim_obs) SIMULATE{y_i(i,m) = rtweedie(mu_i(i,m), phi(m), tweedie_p);}
+            if (notNA) devresid(i,m) = sdmTMB::devresid_tweedie(y_i(i,m), mu_i(i,m), tweedie_p);
             break;
           }
           case binomial_family: {
             if (poisson_link_delta) {
               if (notNA) tmp_ll = poisson_link_m0_ll(i); // needed for robustness; must be first model component
-              SIMULATE{y_i(i,m) = rbinom(size(i), mu_i(i,m));}
+              if (sim_obs) SIMULATE{y_i(i,m) = rbinom(size(i), mu_i(i,m));}
             } else {
               if (notNA) tmp_ll = dbinom_robust(y_i(i,m), size(i), mu_i(i,m), true);
-              SIMULATE{y_i(i,m) = rbinom(size(i), invlogit(mu_i(i,m)));} // hardcoded invlogit b/c mu_i in logit space
+              if (sim_obs) SIMULATE{y_i(i,m) = rbinom(size(i), invlogit(mu_i(i,m)));} // hardcoded invlogit b/c mu_i in logit space
+              if (notNA) devresid(i,m) = sdmTMB::sign(y_i(i,m) - invlogit(mu_i(i,m))) *
+                pow(-2.*((1-y_i(i,m))*log(1.-invlogit(mu_i(i,m))) + y_i(i,m)*log(invlogit(mu_i(i,m)))), 0.5);
             }
             break;
           }
           case poisson_family: {
             if (notNA) tmp_ll = dpois(y_i(i,m), mu_i(i,m), true);
-            SIMULATE{y_i(i,m) = rpois(mu_i(i,m));}
+            if (sim_obs) SIMULATE{y_i(i,m) = rpois(mu_i(i,m));}
+            if (notNA) devresid(i,m) = sdmTMB::sign(y_i(i,m) - mu_i(i,m)) *
+              pow(2.*(y_i(i,m)*log((Type(1e-10) + y_i(i,m))/mu_i(i,m)) - (y_i(i,m)-mu_i(i,m))), 0.5);
             break;
           }
           case censored_poisson_family: {
             if (notNA) tmp_ll = sdmTMB::dcenspois2(y_i(i,m), mu_i(i,m), upr(i), true);
-            SIMULATE{y_i(i,m) = rpois(mu_i(i,m));}
+            if (sim_obs) SIMULATE{y_i(i,m) = rpois(mu_i(i,m));}
             break;
           }
           case Gamma_family: {
             s1 = exp(ln_phi(m));        // shape
             s2 = mu_i(i,m) / s1;        // scale
             if (notNA) tmp_ll = dgamma(y_i(i,m), s1, s2, true);
-            SIMULATE{y_i(i,m) = rgamma(s1, s2);}
+            if (sim_obs) SIMULATE{y_i(i,m) = rgamma(s1, s2);}
+            if (notNA) devresid(i,m) = sdmTMB::sign(y_i(i,m) - mu_i(i,m)) *
+              pow(2.*( (y_i(i,m)-mu_i(i,m))/mu_i(i,m) - log(y_i(i,m)/mu_i(i,m))), 0.5);
             // s1 = Type(1) / (pow(phi, Type(2)));  // s1=shape, ln_phi=CV,shape=1/CV^2
             // tmp_ll = dgamma(y_i(i,m), s1, mu_i(i,m) / s1, true);
             break;
@@ -925,11 +956,12 @@ Type objective_function<Type>::operator()()
             s1 = log(mu_i(i,m)); // log(mu_i)
             s2 = 2. * s1 - ln_phi(m); // log(var - mu)
             if (notNA) tmp_ll = dnbinom_robust(y_i(i,m), s1, s2, true);
-            SIMULATE { // from glmmTMB
+            if (sim_obs) SIMULATE { // from glmmTMB
               s1 = mu_i(i,m);
               s2 = mu_i(i,m) * (Type(1) + mu_i(i,m) / phi(m));
               y_i(i,m) = rnbinom2(s1, s2);
             }
+            if (notNA) devresid(i,m) = sdmTMB::devresid_nbinom2(y_i(i,m), s1, ln_phi(m));
             break;
           }
           case truncated_nbinom2_family: {
@@ -940,18 +972,19 @@ Type objective_function<Type>::operator()()
             lognzprob = logspace_sub(Type(0), -phi(m) * s3);
             if (notNA) tmp_ll -= lognzprob;
             if (notNA) tmp_ll = zt_lik_nearzero(y_i(i,m), tmp_ll); // from glmmTMB
-            SIMULATE{y_i(i,m) = sdmTMB::rtruncated_nbinom(asDouble(phi(m)), 0, asDouble(mu_i(i,m)));}
+            if (sim_obs) SIMULATE{y_i(i,m) = sdmTMB::rtruncated_nbinom(asDouble(phi(m)), 0, asDouble(mu_i(i,m)));}
             break;
           }
           case nbinom1_family: {
             s1 = log(mu_i(i,m));
             s2 = s1 + ln_phi(m);
             if (notNA) tmp_ll = dnbinom_robust(y_i(i,m), s1, s2, true);
-            SIMULATE { // from glmmTMB
+            if (sim_obs) SIMULATE { // from glmmTMB
               s1 = mu_i(i,m);
               s2 = mu_i(i,m) * (Type(1)+phi(m));
               y_i(i,m) = rnbinom2(s1, s2);
               }
+            if (notNA) devresid(i,m) = sdmTMB::devresid_nbinom2(y_i(i,m), s1, s1 - ln_phi(m));
             break;
           }
           case truncated_nbinom1_family: {
@@ -962,24 +995,27 @@ Type objective_function<Type>::operator()()
             lognzprob = logspace_sub(Type(0), -mu_i(i,m) / phi(m) * s3); // 1-prob(0)
             if (notNA) tmp_ll -= lognzprob;
             if (notNA) tmp_ll = zt_lik_nearzero(y_i(i,m), tmp_ll);
-            SIMULATE{y_i(i,m) = sdmTMB::rtruncated_nbinom(asDouble(mu_i(i,m)/phi(m)), 0, asDouble(mu_i(i,m)));}
+            if (sim_obs) SIMULATE{y_i(i,m) = sdmTMB::rtruncated_nbinom(asDouble(mu_i(i,m)/phi(m)), 0, asDouble(mu_i(i,m)));}
             break;
           }
           case lognormal_family: {
             if (notNA) tmp_ll = sdmTMB::dlnorm(y_i(i,m), log(mu_i(i,m)) - pow(phi(m), Type(2)) / Type(2), phi(m), true);
-            SIMULATE{y_i(i,m) = exp(rnorm(log(mu_i(i,m)) - pow(phi(m), Type(2)) / Type(2), phi(m)));}
+            if (notNA) devresid(i,m) = log(y_i(i,m)) - (log(mu_i(i,m)) - 0.5*exp(2.0*log(phi(m))));
+            if (sim_obs) SIMULATE{y_i(i,m) = exp(rnorm(log(mu_i(i,m)) - pow(phi(m), Type(2)) / Type(2), phi(m)));}
             break;
           }
           case student_family: {
             if (notNA) tmp_ll = sdmTMB::dstudent(y_i(i,m), mu_i(i,m), exp(ln_phi(m)), df, true);
-            SIMULATE{y_i(i,m) = mu_i(i,m) + phi(m) * rt(df);}
+            if (notNA) devresid(i,m) = sdmTMB::devresid_nbinom2(y_i(i,m), s1, s1 - ln_phi(m));
+            if (sim_obs) SIMULATE{y_i(i,m) = mu_i(i,m) + phi(m) * rt(df);}
+
             break;
           }
           case Beta_family: { // Ferrari and Cribari-Neto 2004; betareg package
             s1 = mu_i(i,m) * phi(m);
             s2 = (Type(1) - mu_i(i,m)) * phi(m);
             if (notNA) tmp_ll = dbeta(y_i(i,m), s1, s2, true);
-            SIMULATE{y_i(i,m) = rbeta(s1, s2);}
+            if (sim_obs) SIMULATE{y_i(i,m) = rbeta(s1, s2);}
             break;
           }
           case gamma_mix_family: {
@@ -989,7 +1025,7 @@ Type objective_function<Type>::operator()()
             s2_large = mu_i_large(i) / s1;    // scale
             ll_2 = log(p_mix) + dgamma(y_i(i,m), s1, s2_large, true);
             if (notNA) tmp_ll = sdmTMB::log_sum_exp(ll_1, ll_2);
-            SIMULATE{
+            if (sim_obs) SIMULATE{
               if(rbinom(Type(1),p_mix) == 0) {
                 y_i(i,m) = rgamma(s1, s2);
               } else {
@@ -1002,7 +1038,7 @@ Type objective_function<Type>::operator()()
           ll_1 = log(Type(1. - p_mix)) + sdmTMB::dlnorm(y_i(i,m), log(mu_i(i,m)) - pow(phi(m), Type(2)) / Type(2), phi(m), true);
           ll_2 = log(p_mix) + sdmTMB::dlnorm(y_i(i,m), log(mu_i_large(i)) - pow(phi(m), Type(2)) / Type(2), phi(m), true);
           if (notNA) tmp_ll = sdmTMB::log_sum_exp(ll_1, ll_2);
-          SIMULATE{
+          if (sim_obs) SIMULATE{
             if (rbinom(Type(1), p_mix) == 0) {
               y_i(i,m) = exp(rnorm(log(mu_i(i,m)) - pow(phi(m), Type(2)) / Type(2), phi(m)));;
             } else {
@@ -1019,7 +1055,7 @@ Type objective_function<Type>::operator()()
           ll_1 = log(Type(1. - p_mix)) + dnbinom_robust(y_i(i,m), s1, s2, true);
           ll_2 = log(p_mix) + dnbinom_robust(y_i(i,m), s1_large, s2_large, true);
           if (notNA) tmp_ll = sdmTMB::log_sum_exp(ll_1, ll_2);
-          SIMULATE{
+          if (sim_obs) SIMULATE{
             s1 = mu_i(i,m);
             s2 = mu_i(i,m) * (Type(1) + mu_i(i,m) / phi(m));
             s1_large = mu_i_large(i);
@@ -1034,7 +1070,7 @@ Type objective_function<Type>::operator()()
         }
           case gengamma_family: {
             if (notNA) tmp_ll = sdmTMB::dgengamma(y_i(i,m), mu_i(i,m), phi(m), gengamma_Q, true);
-            SIMULATE{y_i(i,m) = sdmTMB::rgengamma(mu_i(i,m), phi(m), gengamma_Q);}
+            if (sim_obs) SIMULATE{y_i(i,m) = sdmTMB::rgengamma(mu_i(i,m), phi(m), gengamma_Q);}
             break;
           }
         default:
@@ -1046,6 +1082,8 @@ Type objective_function<Type>::operator()()
       }
   }
 
+  // Type deviance = 0.0;
+
   // ------------------ Priors -------------------------------------------------
 
   // Construct special object for MVN distribution; always has mean 0.
@@ -1567,6 +1605,8 @@ Type objective_function<Type>::operator()()
   REPORT(eta_iid_re_i); // IID intercept random effect estimates
   REPORT(jnll_obs); // for cross validation
 
+  REPORT(devresid);
+
   SIMULATE {
     REPORT(y_i);
     REPORT(omega_s);
